import { logger } from "@creations.works/logger";
import { normalizeFqdn } from "@lib/char";

const environment: Environment = {
	port: Number.parseInt(process.env.PORT || "8080", 10),
	host: process.env.HOST || "0.0.0.0",
	development:
		process.env.NODE_ENV === "development" || process.argv.includes("--dev"),
	fqdn: normalizeFqdn(process.env.FQDN) || "http://localhost:8080",
};

function verifyRequiredVariables(): void {
	const requiredVariables = [
		"HOST",
		"PORT",

		"FQDN",
		"BACKEND_URL",
	];

	let hasError = false;

	for (const key of requiredVariables) {
		const value = process.env[key];
		if (value === undefined || value.trim() === "") {
			logger.error(`Missing or empty environment variable: ${key}`);
			hasError = true;
		}
	}

	if (hasError) {
		process.exit(1);
	}
}

export { environment, verifyRequiredVariables };
